@@ -16,7 +16,7 @@ Test::Module - One line description
 
 =for html
 <a href="https://github.com/stevieb9/test-module/actions"><img src="https://github.com/stevieb9/test-module/workflows/CI/badge.svg"/></a>
-<a href='https://coveralls.io/github/stevieb9/test-module?branch=master'><img src='https://coveralls.io/repos/stevieb9/test-module/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
+<a href='https://coveralls.io/github/stevieb9/test-module?branch=main'><img src='https://coveralls.io/repos/stevieb9/test-module/badge.svg?branch=main&service=github' alt='Coverage Status' /></a>
 
 
 =head1 SYNOPSIS
@@ -43,7 +43,7 @@ Steve Bertrand, C<< <steveb at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2021 Steve Bertrand.
+Copyright 2022 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
